# devkit-py
![Continuous Integration](https://github.com/outcome-co/devkit-py/workflows/Continuous%20Integration/badge.svg) ![version-badge](https://img.shields.io/badge/version-5.4.0-brightgreen)

A package containing common dev dependencies for python projects.

## Usage

```sh
poetry add -D outcome-devkit
```

## Development

Run `./bootstrap.sh` when you clone the repository to get set up.
